@@ -44,9 +44,4 @@ struct {
 	__type(key, struct key_t);
 	__type(value, struct value_t);
 	__uint(max_entries, 10000);
-} counts SEC(".maps");
-
-struct task_struct {
-	__u32 pid;
-    __u32 tgid;
-}  __attribute__((preserve_access_index));
\ No newline at end of file
+} counts SEC(".maps");
\ No newline at end of file
