@@ -19,9 +19,12 @@ package collector
 
 import (
 	"github.com/apache/skywalking-rover/pkg/accesslog/common"
+	"github.com/apache/skywalking-rover/pkg/logger"
 	"github.com/apache/skywalking-rover/pkg/module"
 )
 
+var log = logger.GetLogger("accesslog", "collector")
+
 type Collector interface {
 	Start(mgr *module.Manager, context *common.AccessLogContext) error
 	Stop()
@@ -35,5 +38,6 @@ func Collectors() []Collector {
 		connectCollectInstance,
 		tlsCollectInstance,
 		processCollectInstance,
+		zTunnelCollectInstance,
 	}
 }
