@@ -18,9 +18,9 @@
 package common
 
 import (
+	"context"
 	"errors"
 	"fmt"
-	"strings"
 	"sync"
 	"time"
 
@@ -34,7 +34,9 @@ import (
 	"github.com/apache/skywalking-rover/pkg/process/finders/kubernetes"
 	"github.com/apache/skywalking-rover/pkg/tools"
 	"github.com/apache/skywalking-rover/pkg/tools/enums"
+	"github.com/apache/skywalking-rover/pkg/tools/host"
 	"github.com/apache/skywalking-rover/pkg/tools/ip"
+	"github.com/apache/skywalking-rover/pkg/tools/path"
 
 	"github.com/cilium/ebpf"
 
@@ -46,8 +48,13 @@ import (
 	v3 "skywalking.apache.org/repo/goapi/collect/ebpf/accesslog/v3"
 )
 
-// only using to match the remote IP address
-const localAddressPairCacheTime = time.Second * 15
+const (
+	// only using to match the remote IP address
+	localAddressPairCacheTime = time.Second * 15
+
+	// clean the active connection in BPF interval
+	cleanActiveConnectionInterval = time.Second * 20
+)
 
 type addressProcessType int
 
@@ -78,6 +85,11 @@ type ConnectionProcessor interface {
 	OnConnectionClose(event *events.SocketCloseEvent, callback ConnectionProcessFinishCallback)
 }
 
+type FlusherListener interface {
+	// ReadyToFlushConnection notify which connection ready to flush
+	ReadyToFlushConnection(connection *ConnectionInfo, getConnectionFromEvent events.Event)
+}
+
 type ProcessListener interface {
 	OnNewProcessMonitoring(pid int32)
 	OnProcessRemoved(pid int32)
@@ -101,14 +113,15 @@ type ConnectionManager struct {
 	processMonitorMap   *ebpf.Map
 	activeConnectionMap *ebpf.Map
 
-	excludeNamespaces map[string]bool
-	excludeClusters   map[string]bool
+	monitorFilter MonitorFilter
 
 	processors       []ConnectionProcessor
 	processListeners []ProcessListener
 
 	// connection already close but the connection (protocols)log not build finished
 	allUnfinishedConnections map[string]*bool
+
+	flushListeners []FlusherListener
 }
 
 func (c *ConnectionManager) RegisterProcessor(processor ConnectionProcessor) {
@@ -119,6 +132,10 @@ func (c *ConnectionManager) AddProcessListener(listener ProcessListener) {
 	c.processListeners = append(c.processListeners, listener)
 }
 
+func (c *ConnectionManager) RegisterNewFlushListener(listener FlusherListener) {
+	c.flushListeners = append(c.flushListeners, listener)
+}
+
 type addressInfo struct {
 	pid uint32
 }
@@ -129,17 +146,10 @@ type ConnectionInfo struct {
 	RPCConnection *v3.AccessLogConnection
 	MarkDeletable bool
 	PID           uint32
+	Socket        *ip.SocketPair
 }
 
-func NewConnectionManager(config *Config, moduleMgr *module.Manager, bpfLoader *bpf.Loader) *ConnectionManager {
-	excludeNamespaces := make(map[string]bool)
-	for _, ns := range strings.Split(config.ExcludeNamespaces, ",") {
-		excludeNamespaces[ns] = true
-	}
-	excludeClusters := make(map[string]bool)
-	for _, cluster := range strings.Split(config.ExcludeClusters, ",") {
-		excludeClusters[cluster] = true
-	}
+func NewConnectionManager(config *Config, moduleMgr *module.Manager, bpfLoader *bpf.Loader, filter MonitorFilter) *ConnectionManager {
 	mgr := &ConnectionManager{
 		moduleMgr:                moduleMgr,
 		processOP:                moduleMgr.FindModule(process.ModuleName).(process.Operator),
@@ -151,14 +161,62 @@ func NewConnectionManager(config *Config, moduleMgr *module.Manager, bpfLoader *
 		processMonitorMap:        bpfLoader.ProcessMonitorControl,
 		activeConnectionMap:      bpfLoader.ActiveConnectionMap,
 		allUnfinishedConnections: make(map[string]*bool),
-		excludeNamespaces:        excludeNamespaces,
-		excludeClusters:          excludeClusters,
+		monitorFilter:            filter,
+		flushListeners:           make([]FlusherListener, 0),
 	}
 	return mgr
 }
 
-func (c *ConnectionManager) Start() {
+func (c *ConnectionManager) Start(ctx context.Context, accessLogContext *AccessLogContext) {
 	c.processOP.AddListener(c)
+
+	// starting to clean up the un-active connection in BPF
+	go func() {
+		ticker := time.NewTicker(cleanActiveConnectionInterval)
+		for {
+			select {
+			case <-ticker.C:
+				activeConnections := c.activeConnectionMap.Iterate()
+				var conID uint64
+				var activateConn ActiveConnection
+				for activeConnections.Next(&conID, &activateConn) {
+					// if the connection is existed, then check the next one
+					pid, fd := events.ParseConnectionID(conID)
+					if c.checkProcessFDExist(pid, fd) {
+						continue
+					}
+
+					// if the connection is not existed, then delete it
+					if err := c.activeConnectionMap.Delete(conID); err != nil {
+						log.Warnf("failed to delete the active connection, pid: %d, fd: %d, connection ID: %d, random ID: %d, error: %v",
+							pid, fd, conID, activateConn.RandomID, err)
+						continue
+					}
+					log.Debugf("deleted the active connection as not exist in file system, pid: %d, fd: %d, connection ID: %d, random ID: %d",
+						pid, fd, conID, activateConn.RandomID)
+
+					// building and send the close event
+					wapperedEvent := c.OnConnectionClose(&events.SocketCloseEvent{
+						ConnectionID: conID,
+						RandomID:     activateConn.RandomID,
+						StartTime:    0,
+						EndTime:      0,
+						PID:          activateConn.PID,
+						SocketFD:     activateConn.SocketFD,
+						Success:      0,
+					})
+					accessLogContext.Queue.AppendKernelLog(LogTypeClose, wapperedEvent)
+				}
+
+			case <-ctx.Done():
+				return
+			}
+		}
+	}()
+}
+
+func (c *ConnectionManager) checkProcessFDExist(pid, fd uint32) bool {
+	return path.Exists(host.GetHostProcInHost(fmt.Sprintf("%d/fd/%d", pid, fd)))
 }
 
 func (c *ConnectionManager) Stop() {
@@ -172,6 +230,10 @@ func (c *ConnectionManager) OnNewProcessExecuting(pid int32) {
 	}
 }
 
+func (c *ConnectionManager) GetExcludeNamespaces() []string {
+	return c.monitorFilter.ExcludeNamespaces()
+}
+
 func (c *ConnectionManager) Find(event events.Event) *ConnectionInfo {
 	connectionKey := fmt.Sprintf("%d_%d", event.GetConnectionID(), event.GetRandomID())
 	data, exist := c.connections.Get(connectionKey)
@@ -197,6 +259,7 @@ func (c *ConnectionManager) Find(event events.Event) *ConnectionInfo {
 				e.GetConnectionID(), e.GetRandomID(), socket.Role, socket.SrcIP, socket.SrcPort, socket.DestIP, socket.DestPort,
 				localAddress.String(), remoteAddress.String())
 		}
+		c.connectionPostHandle(connection, event)
 		return connection
 	}
 	return nil
@@ -263,6 +326,11 @@ func (c *ConnectionManager) connectionPostHandle(connection *ConnectionInfo, eve
 			}
 		}
 	}
+
+	// notify all flush listeners the connection is ready to flush
+	for _, flush := range c.flushListeners {
+		flush.ReadyToFlushConnection(connection, event)
+	}
 }
 
 func (c *ConnectionManager) ProcessIsMonitor(pid uint32) bool {
@@ -292,6 +360,7 @@ func (c *ConnectionManager) buildConnection(event *events.SocketConnectEvent, so
 		RandomID:      event.RandomID,
 		RPCConnection: connection,
 		PID:           event.PID,
+		Socket:        socket,
 	}
 }
 
@@ -301,9 +370,6 @@ func (c *ConnectionManager) buildAddressFromLocalKubernetesProcess(pid uint32, p
 	for _, pi := range c.monitoringProcesses[int32(pid)] {
 		if pi.DetectType() == api.Kubernetes {
 			entity := pi.Entity()
-			if cluster, _, found := strings.Cut(entity.ServiceName, "::"); found && c.excludeClusters[cluster] {
-				continue
-			}
 			podContainer := pi.DetectProcess().(*kubernetes.Process).PodContainer()
 			return &v3.ConnectionAddress{
 				Address: &v3.ConnectionAddress_Kubernetes{
@@ -350,20 +416,20 @@ func (c *ConnectionManager) OnConnectionClose(event *events.SocketCloseEvent) *C
 	return result
 }
 
-func (c *ConnectionManager) savingTheAddress(host string, port uint16, localPid bool, pid uint32) {
+func (c *ConnectionManager) savingTheAddress(hostAddress string, port uint16, localPid bool, pid uint32) {
 	localAddrInfo := &addressInfo{
 		pid: pid,
 	}
-	c.addressWithPid.Set(fmt.Sprintf("%s_%d_%t", host, port, localPid), localAddrInfo, localAddressPairCacheTime)
+	c.addressWithPid.Set(fmt.Sprintf("%s_%d_%t", hostAddress, port, localPid), localAddrInfo, localAddressPairCacheTime)
 	localStr := strRemote
 	if localPid {
 		localStr = strLocal
 	}
-	log.Debugf("saving the %s address with pid cache, address: %s:%d, pid: %d", localStr, host, port, pid)
+	log.Debugf("saving the %s address with pid cache, address: %s:%d, pid: %d", localStr, hostAddress, port, pid)
 }
 
-func (c *ConnectionManager) getAddressPid(host string, port uint16, localPid bool) *addressInfo {
-	addrInfo, ok := c.addressWithPid.Get(fmt.Sprintf("%s_%d_%t", host, port, localPid))
+func (c *ConnectionManager) getAddressPid(hostAddress string, port uint16, localPid bool) *addressInfo {
+	addrInfo, ok := c.addressWithPid.Get(fmt.Sprintf("%s_%d_%t", hostAddress, port, localPid))
 	if ok && addrInfo != nil {
 		return addrInfo.(*addressInfo)
 	}
@@ -416,7 +482,8 @@ func (c *ConnectionManager) isLocalTarget(pair *ip.SocketPair) addressProcessTyp
 
 func (c *ConnectionManager) AddNewProcess(pid int32, entities []api.ProcessInterface) {
 	// filtering the namespace
-	if c.shouldExcludeTheProcess(entities) {
+	monitorProcesses := c.shouldMonitorProcesses(entities)
+	if len(monitorProcesses) == 0 {
 		c.RemoveProcess(pid, entities)
 		return
 	}
@@ -425,9 +492,9 @@ func (c *ConnectionManager) AddNewProcess(pid int32, entities []api.ProcessInter
 	defer c.monitoringProcessLock.Unlock()
 
 	// adding monitoring process and IP addresses
-	c.monitoringProcesses[pid] = entities
+	c.monitoringProcesses[pid] = monitorProcesses
 	c.updateMonitorStatusForProcess(pid, true)
-	for _, entity := range entities {
+	for _, entity := range monitorProcesses {
 		for _, host := range entity.ExposeHosts() {
 			c.localIPWithPid[host] = pid
 		}
@@ -463,26 +530,8 @@ func (c *ConnectionManager) printTotalAddressesWithPid(prefix string) {
 	log.Debugf("----------------------------")
 }
 
-func (c *ConnectionManager) shouldExcludeTheProcess(entities []api.ProcessInterface) bool {
-	// when the process contains multiple entity, and contains the cluster not exclude, then should not exclude the process
-	containsNotExcludeCluster := false
-	for _, entity := range entities {
-		if entity.DetectType() == api.Kubernetes { // for now, we only have the kubernetes detected process
-			namespace := entity.DetectProcess().(*kubernetes.Process).PodContainer().Pod.Namespace
-			if c.excludeNamespaces[namespace] {
-				return true
-			}
-			if cluster, _, found := strings.Cut(entity.Entity().ServiceName, "::"); found {
-				if !c.excludeClusters[cluster] {
-					containsNotExcludeCluster = true
-				}
-			} else {
-				containsNotExcludeCluster = true
-				break
-			}
-		}
-	}
-	return !containsNotExcludeCluster
+func (c *ConnectionManager) shouldMonitorProcesses(entities []api.ProcessInterface) []api.ProcessInterface {
+	return c.monitorFilter.ShouldIncludeProcesses(entities)
 }
 
 func (c *ConnectionManager) RemoveProcess(pid int32, entities []api.ProcessInterface) {
@@ -501,10 +550,11 @@ func (c *ConnectionManager) RemoveProcess(pid int32, entities []api.ProcessInter
 func (c *ConnectionManager) RecheckAllProcesses(processes map[int32][]api.ProcessInterface) {
 	shouldMonitoringProcesses := make(map[int32][]api.ProcessInterface)
 	for pid, p := range processes {
-		if c.shouldExcludeTheProcess(p) {
+		monitorProcesses := c.shouldMonitorProcesses(p)
+		if len(monitorProcesses) == 0 {
 			continue
 		}
-		shouldMonitoringProcesses[pid] = p
+		shouldMonitoringProcesses[pid] = monitorProcesses
 	}
 	// checking the monitoring process
 	c.monitoringProcesses = shouldMonitoringProcesses
@@ -517,6 +567,8 @@ func (c *ConnectionManager) RecheckAllProcesses(processes map[int32][]api.Proces
 		processInBPF[int32(pid)] = true
 	}
 
+	c.monitoringProcessLock.RLock()
+	defer c.monitoringProcessLock.RUnlock()
 	// make sure BPF and user space are consistent
 	for pid := range processInBPF {
 		if _, ok := c.monitoringProcesses[pid]; !ok {
@@ -560,32 +612,36 @@ func (c *ConnectionManager) updateMonitorStatusForProcess(pid int32, monitor boo
 func (c *ConnectionManager) OnBuildConnectionLogFinished() {
 	// delete all connections which marked as deletable
 	// all deletable connection events been sent
-	deletableConnections := make([]string, 0)
+	deletableConnections := make(map[string]bool, 0)
 	c.connections.IterCb(func(key string, v interface{}) {
 		con, ok := v.(*ConnectionInfo)
 		if !ok || con == nil {
 			return
 		}
 		// already mark as deletable or process not monitoring
-		shouldDelete := con.MarkDeletable || len(c.monitoringProcesses[int32(con.PID)]) == 0
+		shouldDelete := con.MarkDeletable || !c.ProcessIsMonitor(con.PID)
 
 		if shouldDelete {
-			deletableConnections = append(deletableConnections, key)
+			deletableConnections[key] = true
 		}
 	})
 
 	deleteFromUnfinished := make([]string, 0)
 	for conKey, processorFinished := range c.allUnfinishedConnections {
 		if *processorFinished {
-			deletableConnections = append(deletableConnections, conKey)
+			deletableConnections[conKey] = true
 			deleteFromUnfinished = append(deleteFromUnfinished, conKey)
+		} else {
+			// if the processor not finished, then ignore it from deletable connections
+			delete(deletableConnections, conKey)
 		}
 	}
 	for _, key := range deleteFromUnfinished {
 		delete(c.allUnfinishedConnections, key)
 	}
 
-	for _, key := range deletableConnections {
+	for key := range deletableConnections {
+		log.Debugf("deleting the connection in manager: %s", key)
 		c.connections.Remove(key)
 	}
 }
