@@ -22,6 +22,7 @@ import (
 	"github.com/apache/skywalking-rover/pkg/core"
 	"github.com/apache/skywalking-rover/pkg/logger"
 	"github.com/apache/skywalking-rover/pkg/module"
+	"github.com/apache/skywalking-rover/pkg/pprof"
 	"github.com/apache/skywalking-rover/pkg/process"
 	"github.com/apache/skywalking-rover/pkg/profiling"
 )
@@ -33,4 +34,5 @@ func init() {
 	module.Register(process.NewModule())
 	module.Register(profiling.NewModule())
 	module.Register(accesslog.NewModule())
+	module.Register(pprof.NewModule())
 }
