@@ -19,36 +19,19 @@ package logger
 
 import (
 	"strings"
-	"sync"
 
 	"github.com/sirupsen/logrus"
 )
 
 var (
 	root = initializeDefaultLogger()
-	once sync.Once
 )
 
-type Config struct {
-	Level string
-}
-
 type Logger struct {
 	*logrus.Entry
 	module []string
 }
 
-// SetupLogger when Bootstrap
-func SetupLogger(config *Config) (err error) {
-	once.Do(func() {
-		err = updateLogger(root, config)
-	})
-	if err != nil {
-		return err
-	}
-	return nil
-}
-
 // GetLogger for the module
 func GetLogger(modules ...string) *Logger {
 	moduleString := ""
@@ -57,3 +40,7 @@ func GetLogger(modules ...string) *Logger {
 	}
 	return &Logger{Entry: root.WithField("module", moduleString), module: modules}
 }
+
+func (l *Logger) Enable(level logrus.Level) bool {
+	return root.IsLevelEnabled(level)
+}
