@@ -23,6 +23,15 @@ const (
 	DefaultLoggerLevel = logrus.InfoLevel
 )
 
+type Config struct {
+	Level string `mapstructure:"level"`
+}
+
+// setupLogger when Bootstrap
+func setupLogger(config *Config) (err error) {
+	return updateLogger(root, config)
+}
+
 func updateLogger(log *logrus.Logger, config *Config) error {
 	level, err := logrus.ParseLevel(config.Level)
 	if err != nil {
@@ -41,3 +50,7 @@ func initializeDefaultLogger() *logrus.Logger {
 	})
 	return l
 }
+
+func (c *Config) IsActive() bool {
+	return true
+}
