@@ -21,6 +21,8 @@ import (
 	"encoding/json"
 	"fmt"
 
+	"github.com/shirou/gopsutil/process"
+
 	"github.com/apache/skywalking-rover/pkg/tools/profiling"
 )
 
@@ -28,14 +30,11 @@ type ProcessDetectType int8
 
 const (
 	_ ProcessDetectType = iota
-	Scanner
 	Kubernetes
 )
 
 func (d ProcessDetectType) Name() string {
-	if d == Scanner {
-		return "Scanner"
-	} else if d == Kubernetes {
+	if d == Kubernetes {
 		return "Kubernetes"
 	}
 	return "not matched"
@@ -52,6 +51,37 @@ type ProcessInterface interface {
 	Entity() *ProcessEntity
 	// ProfilingStat of process
 	ProfilingStat() *profiling.Info
+	// ExeName get execute file name
+	ExeName() (string, error)
+	// OriginalProcess from process library
+	OriginalProcess() *process.Process
+	// DetectProcess from finder
+	DetectProcess() DetectedProcess
+
+	// PortIsExpose check the port is exposed
+	PortIsExpose(port int) bool
+	// DetectNewExposePort add a new detected expose port
+	DetectNewExposePort(port int)
+	// ExposeHosts get all exposed hosts
+	ExposeHosts() []string
+}
+
+// DetectedProcess from the finder
+type DetectedProcess interface {
+	// Pid of process in host
+	Pid() int32
+	// OriginalProcess is works for query the process data
+	OriginalProcess() *process.Process
+	// Entity of process, is related with backend entity
+	Entity() *ProcessEntity
+	// DetectType define the process find type
+	DetectType() ProcessDetectType
+	// ProfilingStat of process
+	ProfilingStat() *profiling.Info
+	// ExposePorts define which ports are exposed
+	ExposePorts() []int
+	// ExposeHosts define which hosts are exposed
+	ExposeHosts() []string
 }
 
 // ProcessEntity is related to backend entity concept
