@@ -56,8 +56,7 @@ func (m *Module) Start(ctx context.Context, mgr *module.Manager) error {
 	if err != nil {
 		return err
 	}
-	processManager, err := finders.NewProcessManager(ctx, mgr, period, m.config.PropertiesReportPeriod,
-		m.config.Scanner, m.config.Kubernetes)
+	processManager, err := finders.NewProcessManager(ctx, mgr, period, m.config.PropertiesReportPeriod, m.config.Kubernetes)
 	if err != nil {
 		return err
 	}
@@ -75,6 +74,34 @@ func (m *Module) Shutdown(ctx context.Context, mgr *module.Manager) error {
 	return m.manager.Shutdown()
 }
 
+func (m *Module) GetAllProcesses() []api.ProcessInterface {
+	return m.manager.GetAllProcesses()
+}
+
 func (m *Module) FindProcessByID(processID string) api.ProcessInterface {
 	return m.manager.FindProcessByID(processID)
 }
+
+func (m *Module) FindAllRegisteredProcesses() []api.ProcessInterface {
+	return m.manager.FindAllRegisteredProcesses()
+}
+
+func (m *Module) FindProcessByPID(pid int32) []api.ProcessInterface {
+	return m.manager.FindProcessByPID(pid)
+}
+
+func (m *Module) AddListener(listener api.ProcessListener) {
+	m.manager.AddListener(listener)
+}
+
+func (m *Module) DeleteListener(listener api.ProcessListener) {
+	m.manager.DeleteListener(listener)
+}
+
+func (m *Module) ShouldMonitor(pid int32) bool {
+	return m.manager.ShouldMonitor(pid)
+}
+
+func (m *Module) NodeName() string {
+	return m.config.Kubernetes.NodeName
+}
