@@ -28,9 +28,10 @@ import (
 	"github.com/hashicorp/go-multierror"
 
 	"github.com/apache/skywalking-rover/pkg/logger"
+	"github.com/apache/skywalking-rover/pkg/module"
 	"github.com/apache/skywalking-rover/pkg/process/api"
 	"github.com/apache/skywalking-rover/pkg/profiling/task/base"
-	"github.com/apache/skywalking-rover/pkg/tools"
+	"github.com/apache/skywalking-rover/pkg/tools/process"
 	"github.com/apache/skywalking-rover/pkg/tools/profiling"
 
 	"golang.org/x/sys/unix"
@@ -40,7 +41,7 @@ import (
 
 // $BPF_CLANG and $BPF_CFLAGS are set by the Makefile.
 // nolint
-//go:generate go run github.com/cilium/ebpf/cmd/bpf2go -target bpfel -cc $BPF_CLANG -cflags $BPF_CFLAGS bpf $REPO_ROOT/bpf/profiling/oncpu.c -- -I$REPO_ROOT/bpf/include
+//go:generate go run github.com/cilium/ebpf/cmd/bpf2go -no-global-types -target bpfel -cc $BPF_CLANG -cflags $BPF_CFLAGS bpf $REPO_ROOT/bpf/profiling/oncpu.c -- -I$REPO_ROOT/bpf/include
 
 var log = logger.GetLogger("profiling", "task", "oncpu")
 
@@ -64,7 +65,7 @@ type Runner struct {
 	stopChan        chan bool
 }
 
-func NewRunner(config *base.TaskConfig) (base.ProfileTaskRunner, error) {
+func NewRunner(config *base.TaskConfig, moduleMgr *module.Manager) (base.ProfileTaskRunner, error) {
 	if config.OnCPU.Period == "" {
 		return nil, fmt.Errorf("please provide the ON_CPU dump period")
 	}
@@ -81,14 +82,18 @@ func NewRunner(config *base.TaskConfig) (base.ProfileTaskRunner, error) {
 	}, nil
 }
 
-func (r *Runner) Init(task *base.ProfilingTask, process api.ProcessInterface) error {
-	r.pid = process.Pid()
+func (r *Runner) Init(task *base.ProfilingTask, processes []api.ProcessInterface) error {
+	if len(processes) != 1 {
+		return fmt.Errorf("the processes count must be 1, current is: %d", len(processes))
+	}
+	curProcess := processes[0]
+	r.pid = curProcess.Pid()
 	// process profiling stat
-	if r.processProfiling = process.ProfilingStat(); r.processProfiling == nil {
+	if r.processProfiling = curProcess.ProfilingStat(); r.processProfiling == nil {
 		return fmt.Errorf("this process could not be profiling")
 	}
 	// kernel profiling stat
-	kernelProfiling, err := tools.KernelFileProfilingStat()
+	kernelProfiling, err := process.KernelFileProfilingStat()
 	if err != nil {
 		log.Warnf("could not analyze kernel profiling stats: %v", err)
 	}
@@ -109,7 +114,7 @@ func (r *Runner) Run(ctx context.Context, notify base.ProfilingRunningSuccessNot
 	funcName := "do_perf_event"
 	replacedPid := false
 	for i, ins := range spec.Programs[funcName].Instructions {
-		if ins.Reference == "MONITOR_PID" {
+		if ins.Reference() == "MONITOR_PID" {
 			spec.Programs[funcName].Instructions[i].Constant = int64(r.pid)
 			spec.Programs[funcName].Instructions[i].Offset = 0
 			replacedPid = true
@@ -119,7 +124,7 @@ func (r *Runner) Run(ctx context.Context, notify base.ProfilingRunningSuccessNot
 		return fmt.Errorf("replace the monitor pid failure")
 	}
 	if err1 := spec.LoadAndAssign(&objs, nil); err1 != nil {
-		log.Fatalf("loading objects: %s", err1)
+		return fmt.Errorf("loading objects: %s", err1)
 	}
 	defer objs.Close()
 	r.bpf = &objs
@@ -204,6 +209,9 @@ func (r *Runner) Stop() error {
 }
 
 func (r *Runner) FlushData() ([]*v3.EBPFProfilingData, error) {
+	if r.bpf == nil {
+		return nil, nil
+	}
 	var stack Event
 	var counter uint32
 	iterate := r.bpf.Counts.Iterate()
