@@ -23,8 +23,6 @@ import (
 	"sort"
 	"strings"
 
-	"github.com/hashicorp/go-multierror"
-
 	"github.com/apache/skywalking-rover/pkg/tools/path"
 )
 
@@ -54,18 +52,17 @@ func (l *GoLibrary) AnalyzeSymbols(filePath string) ([]*Symbol, error) {
 	defer file.Close()
 
 	// exist symbol data
-	symbols, symError := file.Symbols()
-	dySyms, dyError := file.DynamicSymbols()
+	symbols, _ := file.Symbols()
+	dySyms, _ := file.DynamicSymbols()
 	if len(symbols) == 0 && len(dySyms) == 0 {
-		symError = multierror.Append(symError, dyError)
-		return nil, symError
+		return nil, nil
 	}
 	symbols = append(symbols, dySyms...)
 
 	// adapt symbol struct
 	data := make([]*Symbol, len(symbols))
 	for i, sym := range symbols {
-		data[i] = &Symbol{Name: sym.Name, Location: sym.Value}
+		data[i] = &Symbol{Name: sym.Name, Location: sym.Value, Size: sym.Size}
 	}
 
 	sort.SliceStable(data, func(i, j int) bool {
